==> ofscraper-3.10.16.tar.gz: ofscraper-3.10.16/ofscraper/const/constants.py <==
r"""
                                                             
        _____                                    ay           
  _____/ ____\______ ________________    ____   ___________ 
 /  _ \   __\/  ___// ___\_  __ \__  \  /  _ \_/ __ \_  __ \
(  <_> )  |  \___ \\  \___|  | \// __ \(  <_> )  ___/|  | \/
 \____/|__| /____  >\___  >__|  (____  /\____/ \___  >__|   
                 \/     \/           \/            \/         
"""

from ofscraper.const.values.binary import *
from ofscraper.const.values.config import *
from ofscraper.const.values.date import *
from ofscraper.const.values.action.download import *
from ofscraper.const.values.dynamic import *
from ofscraper.const.values.path.files import *
from ofscraper.const.values.path.bytes import *
from ofscraper.const.values.path.path import *
from ofscraper.const.values.general import *
from ofscraper.const.values.action.like import *
from ofscraper.const.values.list import *
from ofscraper.const.values.live import *
from ofscraper.const.values.logger import *
from ofscraper.const.values.action.metadata import *
from ofscraper.const.values.prompts import *
from ofscraper.const.values.req.anon import *
from ofscraper.const.values.req.api import *
from ofscraper.const.values.req.cdm import *
from ofscraper.const.values.req.discord import *
from ofscraper.const.values.req.git import *
from ofscraper.const.values.req.like import *
from ofscraper.const.values.req.mpd import *
from ofscraper.const.values.req.req import *
from ofscraper.const.values.table import *
from ofscraper.const.values.test.test_constants import *
from ofscraper.const.values.time import *
from ofscraper.const.values.url.other_url import *
from ofscraper.const.values.url.url import *
from ofscraper.const.values.progress import *

==> ofscraper-3.11.tar.gz: ofscraper-3.11/ofscraper/const/constants.py <==
r"""
                                                             
        _____                                    ay           
  _____/ ____\______ ________________    ____   ___________ 
 /  _ \   __\/  ___// ___\_  __ \__  \  /  _ \_/ __ \_  __ \
(  <_> )  |  \___ \\  \___|  | \// __ \(  <_> )  ___/|  | \/
 \____/|__| /____  >\___  >__|  (____  /\____/ \___  >__|   
                 \/     \/           \/            \/         
"""

from ofscraper.const.values.binary import *
from ofscraper.const.values.config import *
from ofscraper.const.values.date import *
from ofscraper.const.values.action.download import *
from ofscraper.const.values.dynamic import *
from ofscraper.const.values.path.files import *
from ofscraper.const.values.path.bytes import *
from ofscraper.const.values.path.general import *
from ofscraper.const.values.system import *
from ofscraper.const.values.path.path import *
from ofscraper.const.values.general import *
from ofscraper.const.values.action.like import *
from ofscraper.const.values.list import *
from ofscraper.const.values.live import *
from ofscraper.const.values.logger import *
from ofscraper.const.values.action.metadata import *
from ofscraper.const.values.prompts import *
from ofscraper.const.values.req.anon import *
from ofscraper.const.values.req.api import *
from ofscraper.const.values.req.cdm import *
from ofscraper.const.values.req.discord import *
from ofscraper.const.values.req.git import *
from ofscraper.const.values.req.like import *
from ofscraper.const.values.req.mpd import *
from ofscraper.const.values.req.req import *
from ofscraper.const.values.table import *
from ofscraper.const.values.test.test_constants import *
from ofscraper.const.values.time import *
from ofscraper.const.values.url.other_url import *
from ofscraper.const.values.url.url import *
from ofscraper.const.values.rich import *
